| Title: | Exploring and Analyzing LC-MS Data |
|---|---|
| Description: | This resource hosts tutorials and end-to-end workflows describing how to analyze LC-MS/MS data, from raw files to annotation, using Bioconductor packages. |
| Authors: | Philippine Louail [aut, cre] (ORCID: <https://orcid.org/0009-0007-5429-6846>, fnd: European Union HORIZON-MSCA-2021 project Grant No. 101073062: HUMAN – Harmonising and Unifying Blood Metabolic Analysis Networks), Anna Tagliaferri [ctb] (ORCID: <https://orcid.org/0009-0001-4044-4285>), Vinicius Verri Hernandes [ctb] (ORCID: <https://orcid.org/0000-0002-3057-6460>), Daniel Marques de Sá e Silva [ctb] (ORCID: <https://orcid.org/0000-0002-9674-042X>, fnd: European Union HORIZON-MSCA-2021 project Grant No. 101073062: HUMAN – Harmonising and Unifying Blood Metabolic Analysis Networks), Marilyn De Graeve [aut] (ORCID: <https://orcid.org/0000-0001-6916-401X>), Vilhelm Suksi [aut] (ORCID: <https://orcid.org/0009-0005-1108-518X>), Kozo Nishida [ctb] (ORCID: <https://orcid.org/0000-0001-8501-7319>), Johannes Rainer [aut] (ORCID: <https://orcid.org/0000-0002-6977-7147>) |
| Maintainer: | Philippine Louail <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.5.0 |
| Built: | 2026-05-25 07:51:33 UTC |
| Source: | https://github.com/rformassspectrometry/metabonaut |
This resource hosts tutorials and end-to-end workflows describing how to analyze LC-MS/MS data, from raw files to annotation, using Bioconductor packages.
THe tutorials are rendered and can be found on this page Metabonaut For more information you can find the source code here